@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -170,7 +170,7 @@ GINAC_BIND_UNARCHIVER(Ssum);
    * - If the upper summation index is an integer, perform the sum explicitly.
    * 
    */
-  ex Ssum::eval(int level) const
+  ex Ssum::eval() const
   {
     // check if Ssum simplifies to a Ssum_to_Infinity
     if ( n.is_equal(Infinity) ) return create_Ssum_to_Infinity(letter_list);
@@ -186,7 +186,7 @@ GINAC_BIND_UNARCHIVER(Ssum);
       }
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     return this->hold();
   }
@@ -1092,7 +1092,7 @@ GINAC_BIND_UNARCHIVER(Ssum);
    * Explicit evaluation
    *
    */
-  ex Ssum::eval_explicit(int level) const
+  ex Ssum::eval_explicit() const
   {
     unsigned depth = get_depth();
 
