@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -173,7 +173,7 @@ GINAC_BIND_UNARCHIVER(Zsum);
    * - If the upper summation index is an integer, perform the sum explicitly.
    * 
    */
-  ex Zsum::eval(int level) const
+  ex Zsum::eval() const
   {
     // check if Zsum simplifies to multiple polylog
     if ( n.is_equal(Infinity) ) return create_multiple_polylog(letter_list);
@@ -189,7 +189,7 @@ GINAC_BIND_UNARCHIVER(Zsum);
       }
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     return this->hold();
   }
@@ -876,7 +876,7 @@ GINAC_BIND_UNARCHIVER(Zsum);
    * Explicit evaluation
    *
    */
-  ex Zsum::eval_explicit(int level) const
+  ex Zsum::eval_explicit() const
   {
     unsigned depth = get_depth();
 
