@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -35,6 +35,66 @@ namespace nestedsums {
 
 using namespace GiNaC;
 
+  /**
+   *
+   * A helper function to force the evaluation of sub-expressions.
+   *
+   * This function distributes over the container classes add, mul, ncmul and power.
+   *
+   */
+  ex nestedsums_helper_eval(const ex & expr)
+  {
+    // addition
+    if ( is_a<add>(expr))
+      {
+	int up_limit = expr.nops();
+	exvector res_exvector;
+	res_exvector.reserve(up_limit);
+
+	for (int j=0;j<up_limit;j++)
+	    res_exvector.push_back( nestedsums_helper_eval(expr.op(j)) );
+
+	return (new add(res_exvector))->setflag(status_flags::dynallocated);
+      }
+
+    // multiplication
+    if ( is_a<mul>(expr))
+      {
+	int up_limit = expr.nops();
+	exvector res_exvector;
+	res_exvector.reserve(up_limit);
+
+	for (int j=0;j<up_limit;j++)
+	    res_exvector.push_back( nestedsums_helper_eval(expr.op(j)) );
+
+	return (new mul(res_exvector))->setflag(status_flags::dynallocated);
+      }
+
+
+    // ncmultiplication
+    if ( is_a<ncmul>(expr))
+      {
+	int up_limit = expr.nops();
+	exvector res_exvector;
+	res_exvector.reserve(up_limit);
+
+	for (int j=0;j<up_limit;j++)
+	    res_exvector.push_back( nestedsums_helper_eval(expr.op(j)) );
+
+	return (new ncmul(res_exvector))->setflag(status_flags::dynallocated);
+      }
+
+    // power
+    if ( is_a<power>(expr) )
+      {
+	ex base = nestedsums_helper_eval( expr.op(0) );
+	ex exponent = nestedsums_helper_eval( expr.op(1) );
+	return (new power(base,exponent))->setflag(status_flags::dynallocated);
+      }
+
+    return expr.eval();
+  }
+
   /**
    *
    * A helper routine to expand expressions.
@@ -842,7 +902,7 @@ using namespace GiNaC;
 
     ex res = create_Zsum(Infinity,_empty_list);
     ex letter = create_letter(1-x,1);
-    ex Z0 = create_classical_polylog(lst(letter));
+    ex Z0 = create_classical_polylog(lst{letter});
     ex Zn = 1;
 
     for (k=1;k<order;k++)
