@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -228,10 +228,10 @@ GINAC_BIND_UNARCHIVER(list_of_tgamma);
    * If the index is an integer, the object is evaluated explicitly.
    *
    */
-  ex list_of_tgamma::eval(int level) const
+  ex list_of_tgamma::eval() const
   {
 
-    if ( index.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( index.info(info_flags::integer) ) return this->eval_explicit();
 
     // default
     return this->hold();
@@ -324,7 +324,7 @@ GINAC_BIND_UNARCHIVER(list_of_tgamma);
    * The job is delegated to the function nestedsums_helper_expand_lst_tgamma_fct.
    *
    */
-  ex list_of_tgamma::eval_explicit(int level) const
+  ex list_of_tgamma::eval_explicit() const
   {
     unsigned depth = get_depth();
 
