@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -317,7 +317,7 @@ GINAC_BIND_UNARCHIVER(ratio_of_tgamma);
    * If the index is an integer and the status flag not equal to no_eval_to_scalar, the object is evaluated explicitly.
    *
    */
-  ex ratio_of_tgamma::eval(int level) const
+  ex ratio_of_tgamma::eval() const
   {
 
     if ( flag_expand_status==expand_status::expansion_required )
@@ -400,7 +400,7 @@ GINAC_BIND_UNARCHIVER(ratio_of_tgamma);
       } // end if expansion_required
 
     if ( ( index.info(info_flags::integer) ) 
-	 && (flag_expand_status != expand_status::no_eval_to_scalar)) return this->eval_explicit(level);
+	 && (flag_expand_status != expand_status::no_eval_to_scalar)) return this->eval_explicit();
 
     // default
     return this->hold();
@@ -441,13 +441,13 @@ GINAC_BIND_UNARCHIVER(ratio_of_tgamma);
    * Explicit evaluation with the help of nestedsums_helper_expand_tgamma_fct.
    *
    */
-  ex ratio_of_tgamma::eval_explicit(int level) const
+  ex ratio_of_tgamma::eval_explicit() const
   {
     if ( index.info(info_flags::integer) )
       {
 	return nestedsums_helper_expand_lst_tgamma_fct(
-	       lst(index+a1+b1*expansion_parameter,1+b2*expansion_parameter),
-	       lst(index+a2+b2*expansion_parameter,1+b1*expansion_parameter),
+	       lst{index+a1+b1*expansion_parameter,1+b2*expansion_parameter},
+	       lst{index+a2+b2*expansion_parameter,1+b1*expansion_parameter},
 						       expansion_parameter,order);
       } // end if index is integer
 
