@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -310,7 +310,7 @@ GINAC_BIND_UNARCHIVER(transcendental_fct_type_B);
    * The result is converted to a standard form, using convert_Zsums_to_standard_form.
    *
    */
-  ex transcendental_fct_type_B::eval(int level) const
+  ex transcendental_fct_type_B::eval() const
   {
 #ifdef _DEBUG
     time_t time_start;
@@ -586,7 +586,7 @@ GINAC_BIND_UNARCHIVER(transcendental_fct_type_B);
 	  }
 
 	// poles for n=1,... ?
-	if (flag_n) return convert_Zsums_to_standard_form(term_00 + term_10 + term_01 + this->shift_plus_one(), lst(expansion_parameter));
+	if (flag_n) return convert_Zsums_to_standard_form(term_00 + term_10 + term_01 + this->shift_plus_one(), lst{expansion_parameter});
 
 	for ( k=0;k<lst_i_num.nops();k++)
 	  {
@@ -685,7 +685,7 @@ GINAC_BIND_UNARCHIVER(transcendental_fct_type_B);
 	// ---------------------------------------------------
 	// done
 
-	ex res = convert_Zsums_to_standard_form(term_00 + term_10 + term_01 + term_11, lst(expansion_parameter));
+	ex res = convert_Zsums_to_standard_form(term_00 + term_10 + term_01 + term_11, lst{expansion_parameter});
 
 #ifdef _DEBUG
 	// measuring time end here
