@@ -5,7 +5,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -275,7 +275,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_A);
    * 
    *
    */
-  ex transcendental_sum_type_A::eval(int level) const
+  ex transcendental_sum_type_A::eval() const
   {
 #ifdef _DEBUG
     if ( _debug_level & 1 ) 
@@ -638,7 +638,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_A);
 
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     // default
     //
@@ -698,10 +698,10 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_A);
    */
   ex transcendental_sum_type_A::hash_data(void) const
   {
-    return lst(n,
+    return lst{n,
 	       ex_to<basic_letter>(letter).forget_index(),
 	       ex_to<Zsum>(subsum).get_letter_list()
-	       );
+	       };
   }
 
   /**
@@ -1015,7 +1015,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_A);
    * Explicit evaluation
    *
    */
-  ex transcendental_sum_type_A::eval_explicit(int level) const
+  ex transcendental_sum_type_A::eval_explicit() const
   {
     // n is a integer : evaluate the sum
     if ( n.info(info_flags::integer) )
@@ -1292,14 +1292,14 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_A);
       ex expr = 
 	create_transcendental_sum_type_A_and_set_gammas(nn,i,l,v,ss,eps,o,
 							expand_status::expansion_required);
-      expr = nestedsums_helper_sort(expr,lst(eps));
+      expr = nestedsums_helper_sort(expr,lst{eps});
 
       _nestedsums_evaluation_veto_type_A = expand_status::adjust_summation_index;
-      expr = expr.eval();
-      expr = nestedsums_helper_sort(expr,lst(eps));
+      expr = nestedsums_helper_eval(expr);
+      expr = nestedsums_helper_sort(expr,lst{eps});
 
       _nestedsums_evaluation_veto_type_A = expand_status::zombie;
-      expr = expr.eval();
+      expr = nestedsums_helper_eval(expr);
 
       return expr;
     }
