@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -371,7 +371,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_B);
    * \f]
    *
    */
-  ex transcendental_sum_type_B::eval(int level) const
+  ex transcendental_sum_type_B::eval() const
   {
 #ifdef _DEBUG
     if ( _debug_level & 2 ) 
@@ -922,7 +922,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_B);
 
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     // default
     //
@@ -1554,7 +1554,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_B);
    * Explicit evaluation
    *
    */
-  ex transcendental_sum_type_B::eval_explicit(int level) const
+  ex transcendental_sum_type_B::eval_explicit() const
   {
     // n is a integer : evaluate the sum
     if ( n.info(info_flags::integer) )
@@ -1755,10 +1755,10 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_B);
       ex expr = 
 	create_transcendental_sum_type_B_and_set_gammas(nn,i,l,lr,v,vr,ss,ssr,eps,o,
 							expand_status::expansion_required);
-      expr = nestedsums_helper_sort(expr,lst(eps));
+      expr = nestedsums_helper_sort(expr,lst{eps});
 
       _nestedsums_evaluation_veto_type_B = expand_status::zombie;
-      expr = expr.eval();
+      expr = nestedsums_helper_eval(expr);
 
       return expr;
   }
