@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -307,7 +307,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_C);
    * The evaluation of the Csum is done in its proper evaluation routine.
    *
    */
-  ex transcendental_sum_type_C::eval(int level) const
+  ex transcendental_sum_type_C::eval() const
   {
 #ifdef _DEBUG
     if ( _debug_level & 4 ) 
@@ -683,7 +683,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_C);
 
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     // default
     return this->hold();
@@ -739,10 +739,10 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_C);
    */
   ex transcendental_sum_type_C::hash_data(void) const
   {
-    return lst(n,
+    return lst{n,
 	       ex_to<basic_letter>(letter).forget_index(),
 	       ex_to<Ssum>(subsum).get_letter_list()
-	       );
+	       };
   }
 
   /**
@@ -1056,7 +1056,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_C);
    * Explicit evaluation
    *
    */
-  ex transcendental_sum_type_C::eval_explicit(int level) const
+  ex transcendental_sum_type_C::eval_explicit() const
   {
     // n is a integer : evaluate the sum
     if ( n.info(info_flags::integer) )
@@ -1313,10 +1313,10 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_C);
       ex expr = 
 	create_transcendental_sum_type_C_and_set_gammas(nn,i,l,v,ss,eps,o,
 							expand_status::expansion_required);
-      expr = nestedsums_helper_sort(expr,lst(eps));
+      expr = nestedsums_helper_sort(expr,lst{eps});
 
       _nestedsums_evaluation_veto_type_C = expand_status::zombie;
-      expr = expr.eval();
+      expr = nestedsums_helper_eval(expr);
 
       return expr;
     }
