@@ -6,7 +6,7 @@
  */
 
 /*
- *  gTybalt Copyright (C) 2001 Stefan Weinzierl
+ *  Copyright (C) 2001-2017 Stefan Weinzierl
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -520,7 +520,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_D);
    * \f]
    *
    */
-  ex transcendental_sum_type_D::eval(int level) const
+  ex transcendental_sum_type_D::eval() const
   {
 #ifdef _DEBUG
     if ( _debug_level & 8 ) 
@@ -1321,7 +1321,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_D);
 
 
     // n integer
-    if ( n.info(info_flags::integer) ) return this->eval_explicit(level);
+    if ( n.info(info_flags::integer) ) return this->eval_explicit();
 
     // default
     return this->hold();
@@ -1948,7 +1948,7 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_D);
    * Explicit evaluation
    *
    */
-  ex transcendental_sum_type_D::eval_explicit(int level) const
+  ex transcendental_sum_type_D::eval_explicit() const
   {
     // n is a integer : evaluate the sum
     if ( n.info(info_flags::integer) )
@@ -2329,10 +2329,10 @@ GINAC_BIND_UNARCHIVER(transcendental_sum_type_D);
       ex expr = 
 	create_transcendental_sum_type_D_and_set_gammas(nn,i,l,lr,v,vr,ss,ssr,eps,o,
 							expand_status::expansion_required);
-      expr = nestedsums_helper_sort(expr,lst(eps));
+      expr = nestedsums_helper_sort(expr,lst{eps});
 
       _nestedsums_evaluation_veto_type_D = expand_status::zombie;
-      expr = expr.eval();
+      expr = nestedsums_helper_eval(expr);
 
       return expr;
 
